usl.solve.nls: Solve a USL model using non linear regression
Description
This function solves a USL model using non linear regression with least
squares. It uses the function nls with the "port"
algorithm to perform the calculation. All restrictions of the algorithm
apply.
Usage
usl.solve.nls(model)
Arguments
model
A data frame with two columns containing the values of the
predictor variable in the first column and the values of the response
variable in the second column.
Value
A list containing three elements: the scale.factor of the model,
the model coefficients sigma and kappa.