usl.solve.nlxb: Solve a USL model using non linear regression
Description
This function solves a USL model using non linear regression with least
squares. It uses the function nlxb from the nlmrt
package to perform the calculation.
Usage
usl.solve.nlxb(model)
Arguments
model
A data frame with two columns containing the values of the
predictor variable in the first column and the values of the response
variable in the second column.
Value
A list containing three elements: the scale.factor of the model,
the model coefficients sigma and kappa.
References
John C. Nash. nlmrt: Functions for nonlinear least squares
solutions, 2013. R package version 2013-8.10.