usl.solve.lm: Solve a USL model using a transformation to a 2nd degree polynom
Description
This function solves a USL model using the transformation introduced in
sections 5.5.1 - 5.5.3 of Guerrilla Capacity Planning.
Usage
usl.solve.lm(model)
Arguments
model
A data frame with two columns containing the values of the
predictor variable in the first column and the values of the response
variable in the second column.
Value
A list containing three elements: the scale.factor of the model,
the model coefficients sigma and kappa.
References
Neil J. Gunther. Guerrilla Capacity Planning: A Tactical
Approach to Planning for Highly Scalable Applications and Services.
Springer, Heidelberg, Germany, 1st edition, 2007.